@@ -1,6 +1,7 @@
 /*
  * gst-cdrom.c: Gstreamer Audio CD controlling functions.
  *
+ * Copyright (C) 2001 Iain Holmes <iain@ximian.com>
  * Copyright (C) 2005 Tim-Philipp Müller <tim centricular net>
  *
  * Remaining issues:
@@ -182,11 +183,16 @@ gst_cdrom_is_cdrom_device (GnomeCDRom * cdrom, const char *device,
     int fd;
 
     fd = open (device, O_RDONLY | O_NONBLOCK);
-    if (fd > 0) {
-      if (ioctl (fd, GST_CDROM_IOCTL_CDCAPABILITY_REQUEST, 0) >= 0)        
+    if (fd >= 0) {
+      if (ioctl (fd, GST_CDROM_IOCTL_CDCAPABILITY_REQUEST, 0) >= 0) {
         res = TRUE;
+      } else {
+        GST_DEBUG ("ioctl() failed: %s", g_strerror (errno));
+      }
 
       close (fd);
+    } else {
+      GST_DEBUG ("open() failed: %s", g_strerror (errno));
     }
   }
 
@@ -280,7 +286,8 @@ gst_cdrom_eject (GnomeCDRom * gnome_cdrom, GError ** error)
   } else {
     GST_DEBUG ("tray seems to be open, closing tray ...");
     /* Try to close the tray if it's open */
-    res = gnome_cdrom_close_tray (gnome_cdrom, error); ///// FIXME: use gst_cdrom_close_tray() directly once implemented /////
+    /* FIXME: use gst_cdrom_close_tray() directly once implemented */
+    res = gnome_cdrom_close_tray (gnome_cdrom, error);
   }
 
   /* FIXME: update our status in cdrom->priv->status as well? */
@@ -820,7 +827,7 @@ gst_cdrom_set_device (GnomeCDRom *gnome_cdrom, const char *dev, GError **err)
   return TRUE;
 }
 
-/********** FIXME: see if there's anything else we need to do here ******/
+/* FIXME: see if there's anything else we need to do here */
 
 static void
 gst_cdrom_update_cd (GnomeCDRom * gnome_cdrom)
@@ -974,7 +981,7 @@ gst_cdrom_update_tray_status (GstCDRom * cdrom, GError ** error)
   return FALSE;
 }
 
-/********** FIXME: do tray status checking ******/
+/* FIXME: do tray status checking */
 
 static gboolean
 gst_cdrom_get_status (GnomeCDRom * gnome_cdrom, GnomeCDRomStatus ** status,
@@ -994,6 +1001,12 @@ gst_cdrom_get_status (GnomeCDRom * gnome_cdrom, GnomeCDRomStatus ** status,
     if (!gst_cdrom_ensure_open (cdrom)) {
       *status = NULL;
       GST_DEBUG ("ensure_open failed");
+      if (error) {
+        /* error message is never shown to user, so no need to translate */
+        *error = g_error_new (GNOME_CDROM_ERROR,
+                              GNOME_CDROM_ERROR_IO,
+                              "Could not open CD.");
+      }
       return FALSE;
     }
   }
